@@ -291,6 +291,8 @@ pref("capability.policy.default.XULControllers.removeController", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerId", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerById", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerCount", "noAccess");
+pref("capability.policy.default.Selection.addSelectionListener", "UniversalXPConnect");
+pref("capability.policy.default.Selection.removeSelectionListener", "UniversalXPConnect");
 
 // Restrictions on the DOM for mail/news - see bugs 66938 and 84545
 pref("capability.policy.mailnews.sites", "mailbox: imap: news:");
@@ -473,7 +475,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 482 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 484 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -607,6 +609,7 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // non-ccTLDs
+pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
@@ -668,7 +671,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 682 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 685 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -803,7 +806,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 851 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 854 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -820,7 +823,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 868 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 871 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -953,15 +956,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1331 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1334 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1518 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1521 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1707 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
-
-//@line 1788 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1710 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 //@line 1791 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+
+//@line 1794 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1037,7 +1040,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1867 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1870 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1096,7 +1099,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 1986 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1989 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1318,11 +1321,11 @@ pref("print.postscript.nativecode.zh-TW", "big5");
 pref("print.postscript.nativefont.zh-TW", "ShanHeiSun-Light-B5-H");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2210 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2213 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2278 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2281 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2304 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2307 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2324 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2327 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
