@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Build script template [20060202]
+# Build script template [20060728]
 
 ### Configurations (edit below):
 
@@ -8,17 +8,16 @@ PREFIX=/usr
 DOCPREFIX=${DOCPREFIX:-/usr/share/doc}
 
 SHORTNAME=firefox
-ORIGVER=1.5.0.4
+ORIGVER=1.5.0.5
 PKGVER=P1
 PACKAGE=$SHORTNAME-${ORIGVER/-/_}-i386-$PKGVER.tgz
 SRCPKG=$SHORTNAME-${ORIGVER/-/_}-i386-$PKGVER-Plamosrc.tar.gz
 
-SRCURL1=http://ftp.mozilla-japan.org/pub/mozilla.org/firefox/releases/1.5.0.4/source/firefox-1.5.0.4-source.tar.bz2
-SRC1=firefox-$ORIGVER-source.tar.bz2
+SRCURL1=http://ftp.mozilla-japan.org/pub/mozilla.org/firefox/releases/1.5.0.5/source/firefox-1.5.0.5-source.tar.bz2
 SRCDIR1=firefox-$ORIGVER
 
-#LOCALEVER=1.5.0.4
-SRC11=firefox-${LOCALEVER:-$ORIGVER}-locales.tar.bz2
+#LOCALEVER=1.5.0.5
+SRC11=download/firefox-${LOCALEVER:-$ORIGVER}-locales.tar.bz2
 SRC11_LOCALES=ja
 SRC11_COOPT=${LOCALEVER:+LOCALES_CO_TAG=FIREFOX_${LOCALEVER/./_}_RELEASE}
 
@@ -27,6 +26,7 @@ PATCH12=patches/firefox-1.0.4-startscript.patch
 PATCH13=patches/firefox-1.5-software-update.patch
 PATCH14=patches/firefox-1.5-no-default-search.patch
 PATCH15=patches/firefox-1.5-libdir.patch
+PATCH16=patches/firefox-1.5-iconpath-fix.patch
 ## Patches imported from FC develop
 PATCH101=patches/firefox-0.7.3-default-plugin-less-annoying.patch
 PATCH102=patches/firefox-0.7.3-psfonts.patch
@@ -36,42 +36,39 @@ PATCH104=patches/firefox-nopangoxft.patch
 PATCH111=patches/firefox-1.5-jplocale-customsearch.patch
 
 SRCURL1111=http://mycroft.mozdev.org/nowrapper/submit-install.php/v/2299/wikipedia-ja.src
-SRC1111=wikipedia-ja.src
 SRCURL1112=http://mycroft.mozdev.org/nowrapper/submit-install.php/i/2299/wikipedia-ja.png
-SRC1112=wikipedia-ja.png
 
 SRCURL1121=http://hirohirotest.hp.infoseek.co.jp/Plugin/googlemaps.src
-SRC1121=googlemaps.src
 SRCURL1122=http://hirohirotest.hp.infoseek.co.jp/Plugin/googlemaps.gif
-SRC1122=googlemaps.gif
 
 SRC12=patches/mozconfig-plamobuild
 SRC13=patches/unix.js
 
 INITSCRIPTS=
 
-if [ ! -f $SRC1 ]; then
-    wget -O $SRC1 $SRCURL1
-fi
-if [ ! -f $SRC1111 ]; then
-    wget -O $SRC1111 $SRCURL1111
-fi
-if [ ! -f $SRC1112 ]; then
-    wget -O $SRC1112 $SRCURL1112
-fi
-if [ ! -f $SRC1121 ]; then
-    wget -O $SRC1121 $SRCURL1121
-fi
-if [ ! -f $SRC1122 ]; then
-    wget -O $SRC1122 $SRCURL1122
-fi
-
 ### Common preparations:
 
 TMPDIR=`pwd`
 SRCROOT=`pwd`
 BUILDROOT=$TMPDIR/.work
 PKGROOT=$BUILDROOT/pkgroot
+
+if [ ! -d $SRCROOT/download ]; then
+    mkdir -p $SRCROOT/download
+fi
+for u in ${!SRCURL*}; do
+    f=SRC${u#SRCURL}
+    if [ -z "${!f}" ]; then
+	declare $f=download/${!u##*/}
+    fi
+    if [ ! -f ${!f} ]; then
+	wget -O ${!f} ${!u}
+    fi
+done
+
+if [ -d $BUILDROOT ]; then
+    rm -rf $BUILDROOT
+fi
 mkdir -p $BUILDROOT
 chown 0.0 $BUILDROOT
 chmod 0755 $BUILDROOT
@@ -100,6 +97,7 @@ cat $SRCROOT/$PATCH12 | (cd browser/app; patch)
 cat $SRCROOT/$PATCH13 | patch -p1
 cat $SRCROOT/$PATCH14 | patch -p1
 cat $SRCROOT/$PATCH15 | patch -p1
+cat $SRCROOT/$PATCH16 | patch -p1
 cat $SRCROOT/$PATCH101 | patch -p1
 cat $SRCROOT/$PATCH102 | patch -p1
 cat $SRCROOT/$PATCH103 | patch -p0
